@@ -1,4 +1,4 @@
-use crate::*;
+use super::*;
 
 pub trait ThreadPoolExt {
     fn spawn<T: Send + 'static, F: FnOnce() -> T + Send + 'static>(
@@ -14,7 +14,7 @@ impl ThreadPoolExt for ThreadPool {
     ) -> futures::channel::oneshot::Receiver<T> {
         let (sender, receiver) = futures::channel::oneshot::channel();
         self.execute(move || {
-            if let Err(_) = sender.send(f()) {
+            if sender.send(f()).is_err() {
                 panic!("Failed to send value");
             }
         });
